.. -*- coding: utf-8 -*-

Schéma des données
------------------

Commencez d'abord par jeter un œil au schéma_ de l'application, puis essayez de vous rappeler que vous naviguez dans un ensemble de données en appliquant des vues aux résultats de requête. Ce site n'est pas un système de gestion de contenu avec des objets dans des répertoires. C'est une interface vers une base de données qui vous permet d'appliquer une vue aux données récupérées.

.. _schéma: ../schema


Relation entre les objets
-------------------------

Une relation est définie pour donner un sens précis entre les éléments. Les relations peuvent être facilement ajoutées ou détruites selon le schéma_ de votre application.
